@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2104';
+our $VERSION = '0.2105';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -494,7 +494,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2104
+version 0.2105
 
 =head1 SYNOPSIS
 
@@ -605,9 +605,11 @@ strategic variations of the prisoner's dilemma.
 Create a new C<Game::Theory::TwoPersonMatrix> object.
 
 Player strategies are given by a hash reference of numbered keys - one for each
-strategy.  Payoffs are given by array references of lists of outcomes.  For
-zero-sum games this is a single payoff list.  For non-zero-sum games this is
-given as two lists - one for each player.
+strategy.  These are each assumed to add to 1.  Otherwise YMMV.
+
+Payoffs are given by array references of lists of outcomes.  For zero-sum games
+this is a single payoff list.  For non-zero-sum games this is given as two lists
+- one for each player.
 
 =head2 expected_payoff()
 
